@@ -19,7 +19,6 @@ test_that("get_lineages() returns all and only all non-NA data points",
 test_that("get_status() is functional",
           {
             x <- load_sample()
-            expect_error(get_status(x[,1:5]))
             expect_error(get_status(x, c("doubtful", "duplicated")))
             expect_equal(nrow(get_status(x, c("doubtful", "accepted"))), 1260)
           })
@@ -30,3 +29,23 @@ test_that("get_validity() is functional",
             expect_error(get_validity(x, rank = "species"))
             expect_message(get_validity(x, rank = "kingdom", valid = FALSE), "Term conversion carried out on kingdom taxonomic rank")
           })
+
+test_that("get_inconsistencies() is functional",
+          {
+            x <- get_lineages(load_sample())
+            kingdom <- get_validity(x, rank = "kingdom", valid = FALSE)
+            family <- get_validity(x, rank = "family", valid = FALSE)
+            candidates <- list(kingdom, family)
+            expect_equal(length(get_inconsistencies(candidates, uninomials = FALSE)), 2)
+          })
+test_that("get_taxa() is functional",
+          {
+            x <- load_sample()
+            expect_equal(nrow(get_taxa(x, kingdom = "Animalia",
+                                  phylum = "Chordata",
+                                  class = "Mammalia",
+                                  order = "Carnivora",
+                                  family = "Miacidae",
+                                  genus = "Miacis",
+                                  species = "deutschi" )), 1)
+          })
